<?php

namespace Drupal\Tests\commerce_migrate_commerce\Functional\commerce1;

use Drupal\Tests\commerce_migrate\Functional\MigrateUpgradeReviewPageTestBase;

/**
 * Tests migrate upgrade review page for Commerce 1.
 *
 * @group commerce_migrate
 * @group commerce_migrate_commerce1
 */
class MigrateUpgradeReviewPageTest extends MigrateUpgradeReviewPageTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'action',
    'address',
    'commerce',
    'commerce_log',
    'commerce_migrate',
    'commerce_migrate_commerce',
    'commerce_order',
    'commerce_payment',
    'commerce_price',
    'commerce_product',
    'commerce_store',
    'entity',
    'entity_reference_revisions',
    'inline_entity_form',
    'path',
    'profile',
    'state_machine',
    'text',
    'views',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->loadFixture(drupal_get_path('module', 'commerce_migrate_commerce') . '/tests/fixtures/ck2.php');
  }

  /**
   * {@inheritdoc}
   */
  protected function getSourceBasePath() {
    return __DIR__ . '/files';
  }

  /**
   * {@inheritdoc}
   */
  protected function getAvailablePaths() {
    return [
      'action',
      'addressfield',
      'block',
      'blog',
      'bulk_export',
      'color',
      'comment',
      'commerce',
      'commerce_customer',
      'commerce_line_item',
      'commerce_message',
      'commerce_order',
      'commerce_payment',
      'commerce_price',
      'commerce_product',
      'commerce_product_reference',
      'contact',
      'contextual',
      'ctools',
      'ctools_access_ruleset',
      'ctools_ajax_sample',
      'ctools_custom_content',
      'dashboard',
      'date',
      'date_all_day',
      'date_context',
      'date_migrate',
      'date_repeat',
      'date_repeat_field',
      'date_tools',
      'dblog',
      'email',
      'entity',
      'entity_feature',
      'entity_token',
      'entityreference',
      'field',
      'field_sql_storage',
      'field_ui',
      'file',
      'filter',
      'help',
      'image',
      'link',
      'list',
      'menu',
      'node',
      'openid',
      'options',
      'overlay',
      'page_manager',
      'path',
      'phone',
      'php',
      'poll',
      'profile',
      'rdf',
      'search',
      'search_embedded_form',
      'search_extra_type',
      'search_node_tags',
      'shortcut',
      'simpletest',
      'stylizer',
      'system',
      'taxonomy',
      'term_depth',
      'text',
      'title',
      'toolbar',
      'translation',
      'trigger',
      'user',
      'views_content',
      // Include modules that do not have an upgrade path, defined in the
      // $noUpgradePath property in MigrateUpgradeForm.
      'date_api',
      'date_popup',
      'date_views',
      'number',
      'views_ui',
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getMissingPaths() {
    return [
      'actions_permissions',
      'admin_views',
      'advanced_help',
      'aggregator',
      'basque_services',
      'book',
      'chosen',
      'cloud_zoom',
      'colorbox',
      'commerce_add_to_cart_confirmation',
      'commerce_addressbook',
      'commerce_amex',
      'commerce_authnet',
      'commerce_autosku',
      'commerce_backoffice',
      'commerce_backoffice_content',
      'commerce_backoffice_order',
      'commerce_backoffice_product',
      'commerce_cart',
      'commerce_cba',
      'commerce_checkout',
      'commerce_checkout_progress',
      'commerce_checkout_redirect',
      'commerce_customer_profile_dummy_type',
      'commerce_customer_ui',
      'commerce_discount',
      'commerce_exactor',
      'commerce_exactor_avs',
      'commerce_exactor_calc',
      'commerce_exactor_euc',
      'commerce_extra_price_formatters',
      'commerce_fancy_attributes',
      'commerce_features',
      'commerce_firstdata_gge4',
      'commerce_firstdata_gge4_hpp',
      'commerce_firstdata_gge4_ws',
      'commerce_flat_rate',
      'commerce_hosted_pci',
      'commerce_kiala',
      'commerce_kiala_ps',
      'commerce_kiala_track',
      'commerce_kickstart',
      'commerce_kickstart_block',
      'commerce_kickstart_blog',
      'commerce_kickstart_comment',
      'commerce_kickstart_dfp',
      'commerce_kickstart_help',
      'commerce_kickstart_inline_help',
      'commerce_kickstart_lite_product',
      'commerce_kickstart_menus',
      'commerce_kickstart_merchandising',
      'commerce_kickstart_migrate',
      'commerce_kickstart_order',
      'commerce_kickstart_product',
      'commerce_kickstart_product_ui',
      'commerce_kickstart_reset',
      'commerce_kickstart_search',
      'commerce_kickstart_slideshow',
      'commerce_kickstart_social',
      'commerce_kickstart_taxonomy',
      'commerce_kickstart_user',
      'commerce_line_item_ui',
      'commerce_migrate',
      'commerce_moneybookers',
      'commerce_moneybookers_quickcheckout',
      'commerce_nosto_tagging',
      'commerce_order_ui',
      'commerce_payflow',
      'commerce_payleap',
      'commerce_payment_dummy_offsite',
      'commerce_payment_example',
      'commerce_payment_ui',
      'commerce_paymill',
      'commerce_paypal',
      'commerce_paypal_ec',
      'commerce_paypal_wpp',
      'commerce_paypal_wps',
      'commerce_physical',
      'commerce_product_pricing',
      'commerce_product_pricing_ui',
      'commerce_product_ui',
      'commerce_search_api',
      'commerce_shipping',
      'commerce_shipping_ui',
      'commerce_tax',
      'commerce_tax_ui',
      'commerce_ui',
      'commerce_yotpo',
      'connector',
      'connector_action_default_register_form',
      'countries',
      'countries_configuration',
      'countries_i18n',
      'crumbs',
      'current_search',
      'distro_update',
      'dutch_services',
      'eva',
      'facetapi',
      'farsi_services',
      'favorite_services',
      'features',
      'features_override',
      'fences',
      'field_extractor',
      'forum',
      'forward_services',
      'general_services',
      'german_services',
      'http_client',
      'http_client_oauth',
      'hungarian_services',
      'i18n',
      'i18n_block',
      'i18n_contact',
      'i18n_field',
      'i18n_forum',
      'i18n_menu',
      'i18n_node',
      'i18n_path',
      'i18n_redirect',
      'i18n_select',
      'i18n_string',
      'i18n_sync',
      'i18n_taxonomy',
      'i18n_translation',
      'i18n_user',
      'i18n_variable',
      'image_delta_formatter',
      'inline_conditions',
      'inline_entity_form',
      'italian_services',
      'kameleoon',
      'libraries',
      'lingotek',
      'locale',
      'mailjet',
      'mailjet_campaign',
      'mailjet_event',
      'mailjet_list',
      'mailjet_stats',
      'mailsystem',
      'mailup',
      'mailup_subscribe',
      'menu_attributes',
      'message',
      'message_notify',
      'migrate',
      'migrate_extras',
      'migrate_extras_media',
      'migrate_extras_pathauto',
      'migrate_extras_profile2',
      'migrate_ui',
      'mimemail',
      'mimemail_action',
      'mimemail_compress',
      'module_filter',
      'oauth2_common',
      'oauth_common',
      'oauth_common_providerui',
      'oauthconnector',
      'pathauto',
      'physical',
      'polish_services',
      'print_services',
      'remote_stream_wrapper',
      'rules',
      'rules_admin',
      'rules_i18n',
      'rules_scheduler',
      'russian_services',
      'search_api',
      'search_api_db',
      'search_api_facetapi',
      'search_api_ranges',
      'search_api_sorts',
      'search_api_views',
      'service_links',
      'service_links_displays',
      'service_links_sprites',
      'spanish_services',
      'special_menu_items',
      'statistics',
      'strongarm',
      'swedish_services',
      'syslog',
      'taxonomy_menu',
      'token',
      'toolbar_megamenu',
      'tracker',
      'update',
      'variable',
      'variable_admin',
      'variable_realm',
      'variable_store',
      'variable_views',
      'views',
      'views_bulk_operations',
      'views_megarow',
      'widget_services',
      'yottaa',
    ];
  }

}
